package com.mdd.admin.validate.system;

import com.mdd.common.validator.annotation.IntegerContains;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import javax.validation.constraints.DecimalMin;
import javax.validation.constraints.NotNull;
import org.hibernate.validator.constraints.Length;

@ApiModel("系统岗位创建参数")
public class SystemPostCreateValidate implements Serializable {
   private static final long serialVersionUID = 1L;
   @ApiModelProperty(
      value = "编码",
      required = true
   )
   private @NotNull(
   message = "code参数缺失"
) @Length(
   min = 1,
   max = 30,
   message = "岗位编码必须在1~30个字符内"
) String code;
   @ApiModelProperty(
      value = "岗位名称",
      required = true
   )
   private @NotNull(
   message = "name参数缺失"
) @Length(
   min = 1,
   max = 30,
   message = "岗位名称必须在1~30个字符内"
) String name;
   @IntegerContains(
      values = {0, 1}
   )
   @ApiModelProperty(
      value = "是否停用",
      required = true
   )
   private @NotNull(
   message = "请选择状态"
) Integer isStop = 0;
   @ApiModelProperty("备注信息")
   private @Length(
   max = 250,
   message = "岗位备注不能大于250个字符内"
) String remarks = "";
   @ApiModelProperty(
      value = "排序",
      required = true
   )
   private @NotNull(
   message = "排序号不能为空"
) @DecimalMin(
   value = "0",
   message = "排序号值不能少于0"
) Integer sort = 0;

   public @NotNull(
   message = "code参数缺失"
) String getCode() {
      return this.code;
   }

   public @NotNull(
   message = "name参数缺失"
) String getName() {
      return this.name;
   }

   public @NotNull(
   message = "请选择状态"
) Integer getIsStop() {
      return this.isStop;
   }

   public String getRemarks() {
      return this.remarks;
   }

   public @NotNull(
   message = "排序号不能为空"
) Integer getSort() {
      return this.sort;
   }

   public void setCode(@NotNull(
   message = "code参数缺失"
) String code) {
      this.code = code;
   }

   public void setName(@NotNull(
   message = "name参数缺失"
) String name) {
      this.name = name;
   }

   public void setIsStop(@NotNull(
   message = "请选择状态"
) Integer isStop) {
      this.isStop = isStop;
   }

   public void setRemarks(String remarks) {
      this.remarks = remarks;
   }

   public void setSort(@NotNull(
   message = "排序号不能为空"
) Integer sort) {
      this.sort = sort;
   }

   public boolean equals(Object o) {
      if (o == this) {
         return true;
      } else if (!(o instanceof SystemPostCreateValidate)) {
         return false;
      } else {
         SystemPostCreateValidate other = (SystemPostCreateValidate)o;
         if (!other.canEqual(this)) {
            return false;
         } else {
            label71: {
               Object this$isStop = this.getIsStop();
               Object other$isStop = other.getIsStop();
               if (this$isStop == null) {
                  if (other$isStop == null) {
                     break label71;
                  }
               } else if (this$isStop.equals(other$isStop)) {
                  break label71;
               }

               return false;
            }

            Object this$sort = this.getSort();
            Object other$sort = other.getSort();
            if (this$sort == null) {
               if (other$sort != null) {
                  return false;
               }
            } else if (!this$sort.equals(other$sort)) {
               return false;
            }

            label57: {
               Object this$code = this.getCode();
               Object other$code = other.getCode();
               if (this$code == null) {
                  if (other$code == null) {
                     break label57;
                  }
               } else if (this$code.equals(other$code)) {
                  break label57;
               }

               return false;
            }

            Object this$name = this.getName();
            Object other$name = other.getName();
            if (this$name == null) {
               if (other$name != null) {
                  return false;
               }
            } else if (!this$name.equals(other$name)) {
               return false;
            }

            Object this$remarks = this.getRemarks();
            Object other$remarks = other.getRemarks();
            if (this$remarks == null) {
               if (other$remarks == null) {
                  return true;
               }
            } else if (this$remarks.equals(other$remarks)) {
               return true;
            }

            return false;
         }
      }
   }

   protected boolean canEqual(Object other) {
      return other instanceof SystemPostCreateValidate;
   }

   public int hashCode() {
      int PRIME = true;
      int result = 1;
      Object $isStop = this.getIsStop();
      result = result * 59 + ($isStop == null ? 43 : $isStop.hashCode());
      Object $sort = this.getSort();
      result = result * 59 + ($sort == null ? 43 : $sort.hashCode());
      Object $code = this.getCode();
      result = result * 59 + ($code == null ? 43 : $code.hashCode());
      Object $name = this.getName();
      result = result * 59 + ($name == null ? 43 : $name.hashCode());
      Object $remarks = this.getRemarks();
      result = result * 59 + ($remarks == null ? 43 : $remarks.hashCode());
      return result;
   }

   public String toString() {
      return "SystemPostCreateValidate(code=" + this.getCode() + ", name=" + this.getName() + ", isStop=" + this.getIsStop() + ", remarks=" + this.getRemarks() + ", sort=" + this.getSort() + ")";
   }
}
